Struct DefaultHistory

pub struct DefaultHistory { /* private fields */ }
Default implementation of History that saves history in process memory. This history will not persist across instances of the shell