Struct ShellConfig

pub struct ShellConfig {
    pub hooks: Hooks,
    pub builtins: Builtins,
    pub readline: Box<dyn Readline>,
    pub alias: Alias,
    pub env: Env,
    pub theme: Theme,
    pub lang: Box<dyn Lang>,
    pub plugins: Vec<Box<dyn Plugin>>,
    pub states: States,
    pub history: Box<dyn History>,
    pub config_dir: PathBuf,
    pub keybinding: Keybindings,
    /* private fields */
}
Unified shell config struct

Fields

hooks: Hooks

Runtime hooks, see crate::hooks

builtins: Builtins

Builtin shell commands, see crate::builtin

readline: Box<dyn Readline>

Readline implementation

alias: Alias

Aliases, see crate::alias

env: Env

Environment variables, see crate::env

theme: Theme

Color theme, see crate::theme

lang: Box<dyn Lang>

Command language

plugins: Vec<Box<dyn Plugin>>

Plugins, see crate::plugin

states: States

Globally accessible state, see crate::state

history: Box<dyn History>

History, see crate::history

config_dir: PathBuf

Configuration directory, easy access in the shell

keybinding: Keybindings

Keybindings, see crate::keybinding

Implementations

Source

impl ShellConfig

pub fn run(self) -> Result<(), Error>

Start up the shell

This function contains the main loop of the shell and thus will block for the entire execution of the shell.