pub struct DefaultHistory { /* private fields */ }Expand description
Default implementation of History that saves history in process memory. This history will not persist across instances of the shell